==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/person/provoznidenikcontroller.php <==
<?php
/** roman.szablatura, 14.02.2016 */

namespace Ron\Personalistika;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\RonPortal\Prava;
use Ron\RonPortal\PravaNaOsoby;
use Ron\RonPortal\ProvozniDenikBrowser;
use Ron\RonPortal\ProvozniDenikFormular;
use Ron\RonPortal\User;
use Ron\StringUtils;
use Ron\TextManager;
use Ron\RonPortal\RonPortalSettings;
use function Ron\ronText;


class ProvozniDenikController extends HttpController
{
    /**
     * @var Database
     */
    private $database;
    /**
     * @var PravaNaOsoby
     */
    private $pravaProhlizet;
    /**
     * @var PravaNaOsoby
     */
    private $pravaEditovat;

    /**
     * UchazeciController constructor.
     * @param Database $database databaze
     * @throws Exception
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        Prava::nactiPravaUzivatele($database, User::getRC());
        $this->pravaProhlizet = Prava::vratPrava('pr_denik_read');
        $this->pravaEditovat = Prava::vratPrava('pr_denik_write');
    }


    /**
     * @param Database $database
     * @param string $rc
     * @param int $datum
     * @return string
     * @throws Exception
     * @throws DBException
     */
    public static function vratRozdeleniPlanovaniKapacit($database, $rc, $datum)
    {
        $params = $database->createParameters();
        $sql = "SELECT Rozdeleni
                FROM PlanovaniKapacit
                WHERE PlanovaniKapacit.RC = " . $params->addParameter($rc) .
                " AND PlanovaniKapacit.KodTypuRozdeleni = " .  $params->addParameter(RonPortalSettings::getIntValue(RonPortalSettings::KAPACITY_TYP_ROZDELENI)) .
                " AND PlanovaniKapacit.Datum = " .  $params->addParameter($database->timestampToParam(DateUtils::startOfTheDay($datum)));

        MessageManager::addDebugMessage($sql);

        $cursor = $database->getSqlResult($sql, $params);

        $row = $cursor->fetch();

        $rozdeleni = $row[0];

        if ($row = $cursor->fetch()) {
            throw new Exception(StringUtils::fromUTF8('Je povoleno použití rozdělení z plánování kapacit a uživatel má pro datum ' . StringUtils::format('date',$datum) . ' více přiřazených rozdělení.
                Nastavení: "Použít rozdělení plánování kapacit" je ignorováno.'));
        }
        return $rozdeleni;
    }

    /**
     * @return Redirect|ProvozniDenikFormular
     * @throws Exception
     */
    private function provozniDenikForm()
    {
        if (!($this->pravaEditovat->jsouNejakePrava())) {
            throw new Exception(ronText('Nemate_pravo'));
        }

        $formAction = isset($_POST['formaction'])
            ? $_POST['formaction']
            : $_GET['formaction'];

        $idZaznamu = isset($_POST['formaction'])
            ? $_POST['record']
            : $_GET['record'];

        switch ($formAction) {
            case 'new' :
            case 'insert' :
                break;

            case 'edit' :
            case 'save' :
                if  (!($this->pravaEditovat->priznak && $this->lzeZobrazitZaznam($idZaznamu))) {
                    throw new Exception(ronText('Nemate_pravo'));
                }
                break;

            default:
                throw new Exception('Chyba v ProvozniDenikController::provozniDenikForm!');
        }

        require_once('person/f_provoznidenik.php');
        $f = new ProvozniDenikFormular($this->database);

        if ($f ->handleAction()) {
            return new Redirect(null, '?menuid=provoznidenik');
        }
        return $f;
    }

    /**
     * @param int $idZaznamu
     * @return bool
     * @throws Exception
     * @throws DBException
     */
    private function lzeZobrazitZaznam($idZaznamu)
    {
        $params = $this->database->createParameters();

        $sql = "SELECT ProvozniDenik.KodRozdeleni, ProvozniDenik.RC FROM ProvozniDenik WHERE Id = ". $params->addParameter($idZaznamu);

        $cursor = $this->database->getSqlResult($sql,$params);

        if ($row = $cursor->fetch()) {
            if ($this->pravaEditovat->jePravoNaRozdeleni($this->pravaEditovat->typRozdeleni, $row[0], time(), time())) {
                return true;
            }
            elseif (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity')
                && ($row[0] == self::vratRozdeleniPlanovaniKapacit($this->database,User::getRC(),time()))
                && ($row[1] == User::getRC())
            ) {
                return true;
            }
        }
        return false;
    }

    /**
     * @return string
     * @throws DBException
     * @throws Exception
     */
    private function zobrazSeznam()
    {
        require_once('person/b_provoznidenik.php');
        $b = new ProvozniDenikBrowser($this ->database);
        $b ->load();
        Model::addViewObject($b);

        //pokud je vybrany konkretni typ udalosti (nebo po vlozeni noveho zaznamu], vyhledaji se XML sablony zacinajici kodem typu udalosti,
        // pro kazdou takovou sablonu se zobrazi odkaz na vyplneni
        if ($_SESSION['udalostPD'] || $_SESSION['typUdalostiPD']) {
            $typUdalosti = $_SESSION['typUdalostiPD'] ?: $_SESSION['udalostPD'];

            if ($typUdalosti) {
                $params = $this->database->createParameters();
                $popisTypu = DBUtils::getSqlValue($this->database, "SELECT Popis FROM TypUdalostiPD WHERE Kod = " . $params->addParameter($typUdalosti), $params);
                unset($_SESSION['typUdalostiPD']);

                if ($popisTypu) {
                    $params = $this->database->createParameters();
                    $sql = "SELECT ID, Popis FROM SablonaXMLFormulare WHERE PredavaciProces IS NULL AND Popis LIKE '" . $params->addParameter($popisTypu) . "%'";

                    $cursor = $this->database->getSqlResult($sql);

                    while ($row = $cursor->fetch()) {
                        Model::addViewObject(new TextViewObject("<a href='?menuid=vyplnitdotaznik&record=$row[0]'>" . ronText('PD_vyplnit_formular') . ': ' . $row[1] . "</a>"));
                    }
                }
            }
        }

        return 'view/appview.php';
    }

    /**
     * @param string $action
     * @return string
     * @throws Exception
     */
    public function handleAction($action)
    {
    	if (!($this->pravaProhlizet->jsouNejakePrava() || $this->pravaEditovat->jsouNejakePrava())) {
    		throw new Exception(ronText('Nemate_pravo'));
    	}
    	
        TextManager::getInstance() ->loadStrings('person.ini');

        switch ($_GET['action']) {
            case 'denikform':
                return $this ->provozniDenikForm();

            default:
               return $this->zobrazSeznam();
        }
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/person/provoznidenikcontroller.php <==
<?php
/** roman.szablatura, 14.02.2016 */

namespace Ron\Personalistika;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\MVC\ViewObject;
use Ron\RonPortal\Prava;
use Ron\RonPortal\ProvozniDenikBrowser;
use Ron\RonPortal\User;
use Ron\StringUtils;
use Ron\TextManager;
use Ron\RonPortal\RonPortalSettings;
use RonPortal\Common\ProvozniDenikFormular;
use RonPortal\NeniPravoException;
use RonPortal\PravaNaOsoby;
use function Ron\ronText;


class ProvozniDenikController extends HttpController
{
    /**
     * @var Database
     */
    private $database;
    /**
     * @var PravaNaOsoby
     */
    private $pravaProhlizet;
    /**
     * @var PravaNaOsoby
     */
    private $pravaEditovat;

    /**
     * UchazeciController constructor.
     * @param Database $database databaze
     * @throws Exception
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        Prava::nactiPravaUzivatele($database, User::getRC());
        $this->pravaProhlizet = Prava::vratPrava('pr_denik_read');
        $this->pravaEditovat = Prava::vratPrava('pr_denik_write');
    }


    /**
     * @param Database $database
     * @param string $rc
     * @param int $datum
     * @return string
     * @throws Exception
     * @throws DBException
     */
    public static function vratRozdeleniPlanovaniKapacit($database, $rc, $datum)
    {
        $params = $database->createParameters();
        $sql = "SELECT Rozdeleni
                FROM PlanovaniKapacit
                WHERE PlanovaniKapacit.RC = " . $params->addParameter($rc) .
                " AND PlanovaniKapacit.KodTypuRozdeleni = " .  $params->addParameter(RonPortalSettings::getIntValue(RonPortalSettings::KAPACITY_TYP_ROZDELENI)) .
                " AND PlanovaniKapacit.Datum = " .  $params->addParameter($database->timestampToParam(DateUtils::startOfTheDay($datum)));

        MessageManager::addDebugMessage($sql);

        $cursor = $database->getSqlResult($sql, $params);

        $row = $cursor->fetch();

        $rozdeleni = $row[0];

        if ($row = $cursor->fetch()) {
            throw new Exception(StringUtils::fromUTF8('Je povoleno použití rozdělení z plánování kapacit a uživatel má pro datum ' . StringUtils::format('date',$datum) . ' více přiřazených rozdělení.
                Nastavení: "Použít rozdělení plánování kapacit" je ignorováno.'));
        }
        return $rozdeleni;
    }

    /**
     * @return Redirect|ViewObject
     * @throws Exception
     */
    private function provozniDenikForm()
    {
        if (!($this->pravaEditovat->jsouNejakePrava())) {
            throw new Exception(ronText('Nemate_pravo'));
        }

        $formAction = $_POST['formaction'] ?? $_GET['formaction'] ?? null;

        $idZaznamu = isset($_POST['formaction'])
            ? $_POST['record']
            : ($_GET['record'] ?? null);

        switch ($formAction) {
            case 'new' :
            case 'insert' :
                break;

            case 'edit' :
            case 'save' :
                if  (!($this->pravaEditovat->priznak && $this->lzeZobrazitZaznam($idZaznamu))) {
                    throw new Exception(ronText('Nemate_pravo'));
                }
                break;

            default:
                throw new Exception('Chyba v ProvozniDenikController::provozniDenikForm!');
        }

        $f = new ProvozniDenikFormular($this->database);

        if ($f ->handleAction()) {
            return new Redirect(null, '?menuid=provoznidenik');
        }
        return $f;
    }

    /**
     * @param int $idZaznamu
     * @return bool
     * @throws Exception
     * @throws DBException
     */
    private function lzeZobrazitZaznam($idZaznamu)
    {
        $params = $this->database->createParameters();

        $sql = "SELECT ProvozniDenik.KodRozdeleni, ProvozniDenik.RC FROM ProvozniDenik WHERE Id = ". $params->addParameter($idZaznamu);

        $cursor = $this->database->getSqlResult($sql,$params);

        if ($row = $cursor->fetch()) {
            if ($this->pravaEditovat->jePravoNaRozdeleni($this->pravaEditovat->typRozdeleni, $row[0], time(), time())) {
                return true;
            }
            elseif (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity')
                && ($row[0] == self::vratRozdeleniPlanovaniKapacit($this->database,User::getRC(),time()))
                && ($row[1] == User::getRC())
            ) {
                return true;
            }
        }
        return false;
    }

    /**
     * @return string
     * @throws DBException
     * @throws Exception
     */
    private function zobrazSeznam()
    {
        require_once('person/b_provoznidenik.php');
        $b = new ProvozniDenikBrowser($this ->database);
        $b ->load();
        Model::addViewObject($b);

        //pokud je vybrany konkretni typ udalosti (nebo po vlozeni noveho zaznamu], vyhledaji se XML sablony zacinajici kodem typu udalosti,
        // pro kazdou takovou sablonu se zobrazi odkaz na vyplneni
        if ($_SESSION['udalostPD'] || $_SESSION['typUdalostiPD']) {
            $typUdalosti = $_SESSION['typUdalostiPD'] ?: $_SESSION['udalostPD'];

            if ($typUdalosti) {
                $params = $this->database->createParameters();
                $popisTypu = DBUtils::getSqlValue($this->database, "SELECT Popis FROM TypUdalostiPD WHERE Kod = " . $params->addParameter($typUdalosti), $params);
                unset($_SESSION['typUdalostiPD']);

                if ($popisTypu) {
                    $params = $this->database->createParameters();
                    $sql = "SELECT ID, Popis FROM SablonaXMLFormulare WHERE PredavaciProces IS NULL AND Popis LIKE '" . $params->addParameter($popisTypu) . "%'";

                    $cursor = $this->database->getSqlResult($sql);

                    while ($row = $cursor->fetch()) {
                        Model::addViewObject(new TextViewObject("<a href='?menuid=vyplnitdotaznik&record=$row[0]'>" . ronText('PD_vyplnit_formular') . ': ' . $row[1] . "</a>"));
                    }
                }
            }
        }

        return 'view/appview.php';
    }

    /**
     * @param string $action
     * @return string|ViewObject|Redirect
     * @throws Exception
     */
    public function handleAction($action)
    {
    	if (!($this->pravaProhlizet->jsouNejakePrava() || $this->pravaEditovat->jsouNejakePrava())) {
            throw new NeniPravoException();
    	}
    	
        TextManager::getInstance() ->loadStrings('person.ini');

        switch ($_GET['action'] ?? null) {
            case 'denikform':
                return $this ->provozniDenikForm();

            default:
               return $this->zobrazSeznam();
        }
    }
}
